@@ -21,6 +21,7 @@ public partial class MainWindow: Gtk.Window
 	public string config;
 	public string onladigui, onladiengine, onladiindex, ladiindex;
 	public string onnrpgui, onnrpengine, onnrpglobal, onnrpsize, nrpsize;
+	public string onstateasy, onstatadv, onmultieasy, onmultiadv, multieasy, multiadv;
 	
 	
 	public MainWindow (): base (Gtk.WindowType.Toplevel)
@@ -93,6 +94,12 @@ public partial class MainWindow: Gtk.Window
 				onnrpgui = actualNode["onnrpgui"].InnerText;
 				onnrpsize = actualNode["onnrpsize"].InnerText;
 				nrpsize = actualNode["nrpsize"].InnerText;
+				onstateasy = actualNode["onstateasy"].InnerText;
+				onstatadv = actualNode["onstatadv"].InnerText;
+				onmultiadv = actualNode["onmultiadv"].InnerText;
+				onmultieasy = actualNode["onmultieasy"].InnerText;
+				multiadv = actualNode["multiadv"].InnerText;
+				multieasy = actualNode["multieasy"].InnerText;
 				
 				
 			//set parameters and update GUI
@@ -130,6 +137,8 @@ public partial class MainWindow: Gtk.Window
 			entryvelocity.Text = velocity;
 			spinglide.Value = Convert.ToDouble(glide);
 			spinpitch.Value = Convert.ToDouble(pwd);
+			spinmultiadv.Value = Convert.ToDouble(multiadv);
+			spinmultieasy.Value = Convert.ToDouble(multieasy);
 			entryharmo.Text = harmo;
 			entryfract.Text = fract;
 			entryjsdelay.Text = jsdelay;
@@ -237,6 +246,18 @@ public partial class MainWindow: Gtk.Window
 			if (onfract == "1"){
 					chonfract.Active = true;
 				}
+			if (onmultieasy == "1"){
+					chmultieasy.Active = true;
+				}
+			if (onmultiadv == "1"){
+					chmultiadv.Active = true;
+				}
+			if (onstatadv == "1"){
+					chstatadv.Active = true;
+				}
+			if (onstateasy == "1"){
+					chstateasy.Active = true;
+				}
 				
 				
 			
@@ -274,10 +295,18 @@ public partial class MainWindow: Gtk.Window
 	{
 		if (mode == "easy") {
 			param = param + "-"+easydriver;
-			if (easydriver == "jack"){
+			if (easydriver == "alsa"){
+				param = param+" -audiodev default ";
+			} else if (easydriver == "jack"){
 				if (autoe == "1"){
 					param = param+" -autoconn";
 				}
+				if (onstateasy == "1"){
+					param = param+" -jackstats";
+				}
+				if (onmultieasy == "1"){
+					param = param+" -multi" + multieasy;
+				}
 				if (onjsdisable == "1"){
 					param = param+" -session";
 				}else{
@@ -296,10 +325,18 @@ public partial class MainWindow: Gtk.Window
 		
 		if (mode == "advanced") {
 			param = param + "-audio "+adriver+" -midi "+mdriver;
-			if (adriver == "jack"){
+			if (adriver == "alsa"){
+				param = param+" -audiodev default ";
+			} if (adriver == "jack"){
 				if (autoa == "1"){
 					param = param+" -autoconn";
 				}
+				if (onstatadv == "1"){
+					param = param+" -jackstats";
+				}
+				if (onmultiadv == "1"){
+					param = param+" -multi" + multiadv;
+				}
 				if (onjsdisable == "1"){
 					param = param+" -session";
 				}else{
@@ -424,6 +461,9 @@ public partial class MainWindow: Gtk.Window
 		if (rbmjack.Active.ToString () == "True") {
 			mdriver = "jack";
 		}
+		
+		multiadv = spinmultiadv.Text.ToString ();
+		multieasy = spinmultieasy.Text.ToString ();
 		ogain = spingain.Text.ToString ();
 		igain = spiningain.Text.ToString ();
 		rate = entryrate.Text.ToString ();
@@ -611,7 +651,26 @@ public partial class MainWindow: Gtk.Window
 		}else{
 			onrate = "0";
 		}
-		
+		if (chstateasy.Active.ToString () == "True"){
+			onstateasy = "1";
+		}else{
+			onstateasy = "0";
+		}
+		if (chstatadv.Active.ToString () == "True"){
+			onstatadv = "1";
+		}else{
+			onstatadv = "0";
+		}
+		if (chmultiadv.Active.ToString () == "True"){
+			onmultiadv = "1";
+		}else{
+			onmultiadv = "0";
+		}
+		if (chmultieasy.Active.ToString () == "True"){
+			onmultieasy = "1";
+		}else{
+			onmultieasy = "0";
+		}
 		
 		
 		if (rbeasy.Active.ToString () == "True"){
@@ -642,6 +701,7 @@ public partial class MainWindow: Gtk.Window
 		config = config + "<onladiengine>"+onladiengine+"</onladiengine><onladigui>"+onladigui+"</onladigui><onladiindex>"+onladiindex+"</onladiindex><ladiindex>"+ladiindex+"</ladiindex>";
 		config = config + "<onnrpengine>"+onnrpengine+"</onnrpengine><onnrpgui>"+onnrpgui+"</onnrpgui><onnrpglobal>"+onnrpglobal+"</onnrpglobal><onnrpsize>"+onnrpsize+"</onnrpsize><nrpsize>"+nrpsize+"</nrpsize>";
 		config = config + "<onvoices>"+onvoices+"</onvoices><voices>"+voices+"</voices><tcp>"+tcp+"</tcp><host>"+host+"</host><onhost>"+onhost+"</onhost><ontcp>"+ontcp+"</ontcp><onpreload>"+onpreload+"</onpreload><preload>"+preload+"</preload>";
+		config = config + "<onmultieasy>"+onmultieasy+"</onmultieasy><onmultiadv>"+onmultiadv+"</onmultiadv><onstatadv>"+onstatadv+"</onstatadv><onstateasy>"+onstateasy+"</onstateasy><multiadv>"+multiadv+"</multiadv><multieasy>"+multieasy+"</multieasy>";
 		config = config + "</param></config>";
 		System.IO.File.WriteAllText (System.IO.Directory.GetCurrentDirectory() + "/.monobristol.xml", config);
 	}
@@ -950,6 +1010,12 @@ public partial class MainWindow: Gtk.Window
 		chontcpport.Active = false;
 		chonperiod.Active = false;
 		chonrate.Active = false;
+		chmultieasy.Active = false;
+		chmultiadv.Active = false;
+		chstatadv.Active = false;
+		chstateasy.Active = false;
+		spinmultiadv.Value = 1;
+		spinmultieasy.Value = 1;
 		
 	}
 
@@ -970,6 +1036,12 @@ public partial class MainWindow: Gtk.Window
 		rbejack.Show();
 		chautoadv.Hide ();
 		chautoeasy.Show ();
+		chstatadv.Hide ();
+		chmultiadv.Hide ();
+		chstateasy.Show ();
+		chmultieasy.Show ();
+		spinmultiadv.Hide ();
+		spinmultieasy.Show ();
 	}
 
 	protected virtual void OnRbadv1Clicked (object sender, System.EventArgs e)
@@ -988,6 +1060,12 @@ public partial class MainWindow: Gtk.Window
 		rbejack.Hide ();
 		chautoeasy.Hide ();
 		chautoadv.Show ();
+		chstatadv.Show ();
+		chmultiadv.Show ();
+		chstateasy.Hide ();
+		chmultieasy.Hide ();
+		spinmultiadv.Show ();
+		spinmultieasy.Hide ();
 	}
 
 	protected virtual void OnChnwfToggled (object sender, System.EventArgs e)
